
#ifndef SWMFD_H
#define SWMFD_H


#define SWMFD_VERSAO 103

// Contantes para selele??o de registros do SINTEGRA (fun??o SWEDA_SINTEGRA)
#define opSintegraTipo10         (1 << 0)
#define opSintegraTipo11         (1 << 1)
#define opSintegraTipo60M        (1 << 2)
#define opSintegraTipo60A        (1 << 3)
#define opSintegraTipo60D        (1 << 4)
#define opSintegraTipo60I        (1 << 5)
#define opSintegraTipo60R        (1 << 6)
#define opSintegraTipo60x        (opSintegraTipo60M | opSintegraTipo60A | opSintegraTipo60D | opSintegraTipo60I | opSintegraTipo60R)
#define opSintegraTipo75         (1 << 7)
#define opSintegraTipo90         (1 << 8)

// Constantes para sele?a? de op??es da fun??o
#define opArquivosPasta          (1 << 0)
#define opIncluirSubpastas       (opArquivosPasta | (1 << 1))
#define opListaEmArquivo         (1 << 2)
#define opTransferirMFD          (1 << 3)

#define opMostrarJanela           0
#define opCancelamento           (1 << 10)
#define opOcultarJanela          (1 << 11)
#define opSegundoPlano           (1 << 12)
#define opMinimizarJanela        (1 << 13)
#define opAutoDetectarECF        (1 << 14)

#define opLeituraSimplificada    0
#define opLeituraCompleta        1
#define opCOTEPE1704             0
#define opCSV                    2
#define opTDM                    4
#define opASCII                  8
#define opCriarArquivoTemporario 16

#define opExcluirCOM1            (1 << 4)
#define opExcluirCOM2            (1 << 5)
#define opExcluirCOM3            (1 << 6)
#define opExcluirCOM4            (1 << 7)
#define opExcluirCOM5            (1 << 8)
#define opExcluirCOM6            (1 << 9)

#define opCapturarMFD             (1 << 0)
#define opCapturarMF              (1 << 1)
#define opCapturarSoftwareBasico  (1 << 2)

#define PONTEIRO_NULO         -300


#pragma pack (push, 1)

// Informa??es do contribuinte para gera??o do arquivo SINTEGRA
struct TDadosEstabelecimento
{  char CNPJ[21],                       // C.N.P.J. (opcional)
        IE[21],                         // Inscri??o Estadual (opcional)
        IM[21],                         // Inscri??o Municipal (opcional)
        RazaoSocial[51],                // Nome comercial (Raz?o Social) do contribuinte
                                        // Endere?o:
        Logradouro[51],                 //     - Logradouro
        Numero[11],                     //     - N?mero
        Complemento[31],                //     - Complemento
        Bairro[41],                     //     - Bairro
        Municipio[41],                  //     - Munic?pio onde est? domiciliado o estabelecimento informante
        UF[3],                          //     - Unidade da Federa??o referente ao Munic?pio
        CEP[16],                        //     - CEP (C?digo de Endere?amento Postal)
        Telefone[21],                   // N?mero de telefone para contato
        FAX[21],                        // Fax
        Contato[41];                    // Pessoa respons?vel para contato
        
};      

// Propriedades do arquivo bin?rio retornadas pela fun??o SWEDA_ExtrairInformacoesECF
struct TPropriedadesDispositivo
{
// Sobre o arquivo
   struct TArquivo
   {  short int Tipo;
      char Nome[260],
           Data[11],
           Horario[10],
           Dispositivo[40];
      long Extensao;
   } Arquivo;

// De identifica??o do equipamento
   struct TECF
   {  char Loja[20],
           ECF[10],
           FAB[22],
           Marca[21],
           Modelo[21],
           Tipo[21],
           Berco;
   } ECF;

// Sobre usu?rio(s)
   struct TUsuarioECF
   {  char CNPJ[21],
           IE[21],
           IM[21],
           MFD[22],
           Moeda[7],
           GT[25];
   } Usuario[12];
   short int Usuarios;

// Sobre o software b?sico
   struct TArquivoSB
   {  char Versao[12];               // "01.00.04"
      char Checksum[9];
   } SB;

// Sobre a MFD
   struct TArquivoMFD
   {  char NS[22];
      char Berco;
      long Capacidade;
      long Consumo;
      char DataInstalacao[11];
   } MFD;

   struct TContadores
   {  char COO[7],
           CRZ[7],
           CRO[7];
   } Contadores;
};


// Informa??es sobre o arquivo de origem (Sintegra)
struct TArquivoOrigem
{  char Nome[260];         // Arquivo de origem
   char Data[11];          // Data do arquivo
   char Horario[10];       // Hor?rio do arquivo
   char *Dispositivo;      // Descri??o do dispositivo
   char Loja[5];           // Loja
   char ECF[4];            // N?mero sequencial do ECF
   char FAB[22];           // N/S de fabrica??o do ECF
   short int Tipo;
   long Extensao;          // Extens?o do arquivo em bytes
};

// Contador
struct TContador
{  long Minimo;            // Valor m?ximo do contador
   long Maximo;            // Valor m?nimo do contador
   long Valor;             // Valor corrente do contador
};


// Informa??es repassadas pela fun??o SWEDA_ArquivoSINTEGRA ? rotina de callback da aplica??o.
// Estrutura TInfoCallBackSintegra

struct TInfoCallBackSintegra
{  TDadosEstabelecimento Estabelecimento; // Dados sobre o estabelecimento
   TArquivoOrigem Fila[100];  // Fila de arquivos para processamento
   short int Arquivos;        // N?mero total de arquivos
   TArquivoOrigem Arquivo;    // Informa??es do arquivo em processamento
   short int Sequencial;      // N?mero sequencial do arquivo
   TContador Contador;        // Contador
   long TempoEstimado;        // Tempo estimado de conclus?o em caso de transfer?ncia da MFD
   char Destino[260];         // Nome do arquivo destino
   short int Evento;          // Mensagem
   short int Retorno;         // C?digo retornado ? aplica??o
   short int Tipo;            // Tipo do registro (Mensagem 50)
   char Subtipo;              // Subtipo do registro (Mensagem 50)
   char *Registro;            // Registro (Mensagem 50)
};


struct TInfoCallBackExp
{  struct TArquivoOrigem    // Informa??es do arquivo em processamento
   {  char Nome[260];         // Arquivo de origem
      char Data[11];          // Data do arquivo
      char Horario[10];       // Hor?rio do arquivo
      char *Dispositivo;      // Descri??o do dispositivo
      char Loja[5];           // Loja
      char ECF[4];            // N?mero sequencial do ECF
      char FAB[22];           // N/S de fabrica??o do ECF
      short int Tipo;
      long Extensao;          // Extens?o do arquivo em bytes
      char CNPJ[21];          // CNPJ 
      char IE[21];            // IE
      char IM[21];            // IM
      char Modelo[21];
   } Arquivo;

   short int Formato;
   char Destino[260];         // Nome do arquivo destino
   TContador Contador;        // Contador
   short int Evento;          // Mensagem
   short int Retorno;         // C?digo retornado ? aplica??o
};


// Informa??es repassadas pela fun??o de captura de dispositivos ? rotina de callback da aplica??o.

struct TInfoCallBackCD
{  char Arquivo[260];         // Arquivo de origem
   char NS[22];               // N/S do dispositivo
   char FAB[22];              // N/S de fabrica??o do ECF
   char Modelo[22];           // N/S do dispositivo
   short int Evento;          // Evento
   short int Dispositivo;     // Descri??o do dispositivo
   TContador Contador;        // Contador
   short int Retorno;         // C?digo retornado ? aplica??o
   long TempoEstimado;        // Tempo estimado para conclus?o em segundos
   long TaxaRecepcao;         // Taxa m?dia de recep??o
};


// Par?metros configurados pelo arquivo SWMFD.INI
struct SWMFD_INI
{  char DiretorioSweda[260];
   char FAB[22];
   char MFD[22];
   short int Porta;
   long Velocidade;
   short int ControleFluxo;
};


#pragma pack(pop)


typedef void (_stdcall *TCallBackExp) (TInfoCallBackExp*, void *Instancia);
typedef void (_stdcall *TCallBackSintegra) (TInfoCallBackSintegra*, void *Instancia);
typedef void (_stdcall *TCallBackCD) (TInfoCallBackCD*, void *Instancia);
typedef void (_stdcall *TEventoConexaoPortaFisco) (struct TPropriedadesDispositivo*);
// Funcoes:

#if PLATAFORMA & MSWIN32

#ifndef DLL_IMPORT
#define DLL_IMPORT __declspec (dllimport)
#endif

#else

#ifndef DLL_IMPORT
#define DLL_IMPORT  
#endif

#endif
// Funcoes da SWMFD.DLL

extern "C" DLL_IMPORT short int __stdcall SWEDA_SWMFDVersao();
extern "C" DLL_IMPORT short int __stdcall SWEDA_ExtrairInformacoesECF (char *szNomeArquivo, struct TPropriedadesDispositivo *Buffer, short int Extensao, short int = 0);
extern "C" DLL_IMPORT short int __stdcall SWEDA_ArquivoSINTEGRA (char *, char *, char *, TDadosEstabelecimento*, short int = 0x7FFF, short int = 0, char* = "", char* = "", TCallBackSintegra = 0, void* = 0, short int = 0);
extern "C" DLL_IMPORT      void __stdcall SWEDA_InterromperGeracaoArquivoSINTEGRA();
extern "C" DLL_IMPORT short int __stdcall SWEDA_ReproduzirLeituraMemoriaFiscal (char *szArquivoOrigem, char *szArquivoDestino, char *SelecaoInicial, char *SelecaoFinal, short int Tipo, short int Opcoes = 0, char *Buffer = 0, long Extensao = 0);
extern "C" DLL_IMPORT short int __stdcall SWEDA_ReproduzirFitaDetalhe (char *szArquivoOrigem, char *szArquivoDestino, char *SelecaoInicial, char *SelecaoFinal, short int Opcoes = 0, char *Buffer = 0, long Extensao = 0);
extern "C" DLL_IMPORT short int __stdcall SWEDA_ArquivoEletronicoCOTEPE (char *pszOrigem1, char *pszOrigem2, char *pszArquivoDestino, char *pszSelecaoInicial = "", char *pszSelecaoFinal = "", short int Opcoes = 0);
extern "C" DLL_IMPORT short int __stdcall SWEDA_CapturarDispositivo (short int Dispositivo, short int Opcoes = opMostrarJanela, char *Arquivo = 0, short int Extensao = 0, long Timeout = 15000, TCallBackCD CallBack = 0, void *Instancia = 0);
//extern "C" DLL_IMPORT short int __stdcall SWEDA_DetectarECF (short int Opcoes, short int *PortaDetectada, long *VelocidadeDetectada);
extern "C" DLL_IMPORT short int __stdcall SWEDA_TabelaMercadoriasServicos (char *pszArquivoDestino, char *pszSelecaoInicial, char *pszSelecaoFinal, short int Opcoes = 0, char *pszOrigem = 0, char *pszArquivoLog = 0);


// Fun??es para acesso e altera??o do arquivo de inicializa??o SWMFD.INI
extern "C" DLL_IMPORT      void __stdcall SWMFD_ObterParametrosConfiguracao (SWMFD_INI*, short int);
extern "C" DLL_IMPORT      void __stdcall SWMFD_AlterarParametrosConfiguracao (SWMFD_INI*, short int);

extern "C" DLL_IMPORT      bool __stdcall SWMFD_AbrirPortaFiscal (short int, TEventoConexaoPortaFisco = 0);
extern "C" DLL_IMPORT      void __stdcall SWMFD_FecharPortaFiscal ();

#endif

